==> drupal-6.3-noname-P2.tgz: install/doinst.sh <==
#%% begin initialize drupal-6.3-noname-P2
###################################################################
export LANG=C
export PATH=/bin:/usr/bin:/sbin:/usr/sbin

if [ -r /tmp/SeTT_PX ]; then
  ROOT="`cat /tmp/SeTT_PX`"
fi

APACI_DIR=$ROOT/opt/httpd
PG_DIR=$ROOT/opt/pgsql
WWW=$ROOT/home/www

if [ -f $ROOT/opt/htdocs/drupal6 ]; then
  mv $ROOT/opt/htdocs/drupal6 $ROOT/opt/htdocs/drupal6.bak
fi
(cd $ROOT/opt/htdocs; ln -sf drupal-6.3 drupal6 )

FQDN=`hostname -f`
if [ ".$FQDN" = "." ]; then
  FQDN=localhost
fi

if [ -f $ROOT/opt/htdocs/drupal6/sites/default/settings.php ]; then
  mv $ROOT/opt/htdocs/drupal6/sites/default/settings.php \
     $ROOT/opt/htdocs/drupal6/sites/default/settings.php.bak
fi
sed -e "s%^\$db_url = 'mysql://username:password@localhost/databasename';%\$db_url = 'pgsql://www:pass@localhost/drupal6';%" \
    -e "s%^\$base_url = 'http://localhost';%\$base_url = 'http://$FQDN/drupal6';%" \
   $ROOT/opt/htdocs/drupal6/sites/default/default.settings.php \
    > $ROOT/opt/htdocs/drupal6/sites/default/settings.php

/bin/mkdir -p $ROOT/opt/htdocs/drupal6/files
/bin/chown www.apache $ROOT/opt/htdocs/drupal6/files

/bin/su - postgres -c "sh $ROOT/opt/htdocs/drupal6/custom/create_drupal6_db"


if [ ! -f $WWW/.postgresql/postgresql.crt ]; then
 mkdir -p $WWW/.postgresql
 cp $PG_DIR/data/server.crt $WWW/.postgresql/postgresql.crt
 cp $PG_DIR/data/server.key $WWW/.postgresql/postgresql.key
 chown -R www.apache  $WWW/.postgresql
fi

mkdir -p            $ROOT/opt/htdocs/drupal6/files
chown -R www.apache $ROOT/opt/htdocs/drupal6/files \
                    $ROOT/opt/htdocs/drupal6/themes
chgrp -R apache     $ROOT/opt/htdocs/drupal6

if ! fgrep "drupal6/cron.php" $ROOT/var/spool/cron/crontabs/www 1>/dev/null 2>&1; then
  echo "0  *  *  *  *	wget -O - -q http://$FQDN/drupal6/cron.php" >> $ROOT/var/spool/cron/crontabs/www
fi


echo "To install japanese package drupal see:"      
echo "        http://drupal.jp/drupal6/guide/install-step1" 


#%% end

==> drupal-6.5-noname-P2.tgz: install/doinst.sh <==
#%% begin initialize drupal-6.5-noname-P1
###################################################################
export LANG=C
export PATH=/bin:/usr/bin:/sbin:/usr/sbin

if [ -r /tmp/SeTT_PX ]; then
  ROOT="`cat /tmp/SeTT_PX`"
fi

APACI_DIR=$ROOT/opt/httpd
PG_DIR=$ROOT/opt/pgsql
WWW=$ROOT/home/www

if [ -f $ROOT/opt/htdocs/drupal6 ]; then
  mv $ROOT/opt/htdocs/drupal6 $ROOT/opt/htdocs/drupal6.bak
fi
(cd $ROOT/opt/htdocs; rm -f drupal6; ln -sf drupal-6.5 drupal6 )

FQDN=`hostname -f`
if [ ".$FQDN" = "." ]; then
  FQDN=localhost
fi

if [ -f $ROOT/opt/htdocs/drupal6/sites/default/settings.php ]; then
  mv $ROOT/opt/htdocs/drupal6/sites/default/settings.php \
     $ROOT/opt/htdocs/drupal6/sites/default/settings.php.bak
fi
sed -e "s%^\$db_url = 'mysql://username:password@localhost/databasename';%\$db_url = 'pgsql://www:pass@localhost/drupal6';%" \
    -e "s%^\$base_url = 'http://localhost';%\$base_url = 'http://$FQDN/drupal6';%" \
   $ROOT/opt/htdocs/drupal6/sites/default/default.settings.php \
    > $ROOT/opt/htdocs/drupal6/sites/default/settings.php

/bin/mkdir -p $ROOT/opt/htdocs/drupal6/files
/bin/chown www.apache $ROOT/opt/htdocs/drupal6/files

/bin/su - postgres -c "sh $ROOT/opt/htdocs/drupal6/custom/create_drupal6_db"


if [ ! -f $WWW/.postgresql/postgresql.crt ]; then
 mkdir -p $WWW/.postgresql
 cp $PG_DIR/data/server.crt $WWW/.postgresql/postgresql.crt
 cp $PG_DIR/data/server.key $WWW/.postgresql/postgresql.key
 chown -R www.apache  $WWW/.postgresql
fi

mkdir -p            $ROOT/opt/htdocs/drupal6/files
chown -R www.apache $ROOT/opt/htdocs/drupal6/files \
                    $ROOT/opt/htdocs/drupal6/themes
chgrp -R apache     $ROOT/opt/htdocs/drupal6

if ! fgrep "drupal6/cron.php" $ROOT/var/spool/cron/crontabs/www 1>/dev/null 2>&1; then
  echo "0  *  *  *  *	wget -O - -q http://$FQDN/drupal6/cron.php" >> $ROOT/var/spool/cron/crontabs/www
fi


echo "To install japanese package drupal see:"      
echo "        http://drupal.jp/drupal6/guide/install-step1" 

#%% end
